@@ -363,10 +363,10 @@ class TetrisGame(BaseGame):
 
     def draw_ui(self) -> None:
         """Отрисовка пользовательского интерфейса"""
-        # Левая панель - статистика игры
+        # Левая панель - статистика игры (перемещена выше)
         left_panel_x = 20
-        left_panel_y = 20
-        
+        left_panel_y = 10  # Перемещено выше
+
         # Счет
         score_text = f"Счет: {self.score}"
         score_surface = self.font.render(score_text, True, self.text_color)
@@ -375,14 +375,14 @@ class TetrisGame(BaseGame):
         # Уровень
         level_text = f"Уровень: {self.level}"
         level_surface = self.font.render(level_text, True, self.text_color)
-        self.screen.blit(level_surface, (left_panel_x, left_panel_y + 50))
+        self.screen.blit(level_surface, (left_panel_x, left_panel_y + 30))  # Уменьшен отступ
 
         # Прогресс до следующего уровня
         required_lines = 7 + self.level  # Следующий уровень требует 7 + текущий_уровень линий
         lines_needed = max(0, required_lines - self.lines_cleared)
         progress_text = f"До уровня {self.level + 1}: {lines_needed}"
         progress_surface = self.small_font.render(progress_text, True, self.text_color)
-        self.screen.blit(progress_surface, (left_panel_x, left_panel_y + 100))
+        self.screen.blit(progress_surface, (left_panel_x, left_panel_y + 60))  # Уменьшен отступ
 
         # Состояние игры
         if self.game_over:
@@ -417,12 +417,12 @@ class TetrisGame(BaseGame):
         # Правая панель - управление
         right_panel_x = self.width - 250
         right_panel_y = 20
-        
+
         # Заголовок управления
         controls_title = "Управление:"
         controls_title_surface = self.small_font.render(controls_title, True, self.text_color)
         self.screen.blit(controls_title_surface, (right_panel_x, right_panel_y))
-        
+
         # Управление
         controls = [
             "Стрелки - Движение",
